Index: src/wp-includes/link-template.php
===================================================================
--- src/wp-includes/link-template.php	(revision 43374)
+++ src/wp-includes/link-template.php	(working copy)
@@ -4329,11 +4329,16 @@
 	$privacy_policy_url = get_privacy_policy_url();
 
 	if ( $privacy_policy_url ) {
-		$link = sprintf(
-			'<a class="privacy-policy-link" href="%s">%s</a>',
-			esc_url( $privacy_policy_url ),
-			__( 'Privacy Policy' )
-		);
+		$policy_page_id = (int) get_option( 'wp_page_for_privacy_policy' );
+		$page_title     = get_the_title( $policy_page_id );
+
+		if ( ! empty( $page_title ) ) {
+			$link = sprintf(
+				'<a class="privacy-policy-link" href="%s">%s</a>',
+				esc_url( $privacy_policy_url ),
+				$page_title
+			);
+		}
 	}
 
 	/**
Index: tests/phpunit/tests/link/getThePrivacyPolicyLink.php
===================================================================
--- tests/phpunit/tests/link/getThePrivacyPolicyLink.php	(revision 43374)
+++ tests/phpunit/tests/link/getThePrivacyPolicyLink.php	(working copy)
@@ -71,7 +71,8 @@
 
 	/**
 	 * The function should return a valid link if a privacy policy page has been
 	 * created and set as the `wp_page_for_privacy_policy`.
 	 */
 	public function test_get_the_privacy_policy_link_should_return_valid_link_when_privacy_page_set() {
 		update_option( 'wp_page_for_privacy_policy', self::$privacy_policy_page_id );
@@ -80,6 +81,7 @@
 
 		$this->assertStringStartsWith( '<a', $actual_link );
 		$this->assertContains( self::$privacy_policy_url, $actual_link );
+		$this->assertContains( '>' . WP_TESTS_DOMAIN . ' Privacy Policy</a>', $actual_link );
 		$this->assertStringEndsWith( '</a>', $actual_link );
 	}
 
@@ -108,6 +110,22 @@
 	}
 
 	/**
+	 * The function should return an empty string when there is no page title for the privacy policy.
+	 */
+	public function test_get_the_privacy_policy_link_empty_page_title() {
+		$nameless_page_id = $this->factory->post->create(
+			array(
+				'post_type'  => 'page',
+				'post_title' => '',
+			)
+		);
+
+		update_option( 'wp_page_for_privacy_policy', $nameless_page_id );
+
+		$this->assertEmpty( get_the_privacy_policy_link( self::$before, self::$after ) );
+	}
+
+	/**
 	 * The function should return an empty string when `wp_page_for_privacy_policy` is _not_ configured.
 	 */
 	public function test_get_the_privacy_policy_link_should_return_empty_string_when_privacy_page_not_set() {
@@ -71,7 +71,8 @@
 	/**
 	 * The function should return a valid link if a privacy policy page has been
-	 * created and set as the `wp_page_for_privacy_policy`.
+	 * created and set as the `wp_page_for_privacy_policy`. The post title should
+	 * be used as the link text.
 	 */
 	public function test_get_the_privacy_policy_link_should_return_valid_link_when_privacy_page_set() {
